pub struct InterceptorChain { /* private fields */ }Expand description
An ordered list of CallInterceptors applied to every request.
Interceptors run in registration order for before and reverse order for
after (outermost wraps innermost).
Implementations
Sourceimpl InterceptorChain
impl InterceptorChain
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates an empty InterceptorChain.
Sourcepub fn push<I: CallInterceptor>(&mut self, interceptor: I)
pub fn push<I: CallInterceptor>(&mut self, interceptor: I)
Adds an interceptor to the end of the chain.
Sourcepub async fn run_before(&self, req: &mut ClientRequest) -> ClientResult<()>
pub async fn run_before(&self, req: &mut ClientRequest) -> ClientResult<()>
Runs all before hooks in registration order.
Errors
Returns the first error returned by any interceptor in the chain.
Sourcepub async fn run_after(&self, resp: &ClientResponse) -> ClientResult<()>
pub async fn run_after(&self, resp: &ClientResponse) -> ClientResult<()>
Runs all after hooks in reverse registration order.
Errors
Returns the first error returned by any interceptor in the chain.