pub struct SessionId(/* private fields */);Expand description
Opaque identifier for a client authentication session.
Sessions scope credentials so that a single credential store can manage tokens for multiple simultaneous client instances.
Implementations